void setup() {
  // put your setup code here, to run once:
 
  // This next line will print out the interface status of
  //  all interfaces - note the redirection at the end ensures that
  //  any errors are also captured and sent to the serial
  //  monitor.
  system("ifconfig  > /dev/ttyGS0 2>&1");
 
}
 
void loop() {
  // put your main code here, to run repeatedly:
 
}

