void setup() {
  // put your setup code here, to run once:
  system("ifconfig eth0 192.168.1.1 netmask 255.255.0.0 up");
  system("telnetd -l /bin/sh"); //Start the telnet server on Galileo
}

void loop() {
  // put your main code here, to run repeatedly:

}
